/**
 * Functions for securely storing bearer tokens using OS-level utilities.
 * These functions are limited to credentials and do not provide general
 * encryption for arbitrary data.
 *
 * If you need to store and retrieve sensitive information other
 * than credentials, you should consider using the utilities provided by
 * `file-encryption.ts` instead.
 */
export declare const SERVICE_NAME = "heroku";
/**
 * Removes a stored bearer token using OS-level utilities
 *
 * @param serviceName - The name of the service for which the token is being removed. Defaults to 'heroku'
 * @throws Error if the token cannot be removed or if the platform is not supported
 * @returns Promise that resolves when the token is removed
 *
 * @example
 * ```typescript
 * // Remove token for default service (heroku)
 * removeToken();
 *
 * // Remove token for a specific service
 * removeToken('my-service');
 * ```
 */
export declare function removeToken(serviceName?: string): void;
/**
 * Stores a bearer token securely using OS-level utilities
 *
 * @param token the token to store
 * @param serviceName the name of the service for which the token is being stored. defaults to 'heroku'
 * @returns a promise that resolves when the token is stored
 */
export declare function storeToken(token: string, serviceName?: string): void;
/**
 * Retrieves a stored bearer token securely using OS-level utilities
 *
 * @param serviceName the name of the service for which the token is being stored. defaults to 'heroku'
 * @returns a promise that resolves with the stored token
 */
export declare function retrieveToken(serviceName?: string): string;
